@@ -218,8 +218,9 @@ public :
     virtual int firstColumn() const { return matrix_.firstColumn(); }
     virtual int nextColumn(int j, int f) const  { return matrix_.nextColumn(j, f); } 
     
-    void setMinMax() const {
-    	int nb_rows = rows();
+    virtual void setMinMax() const {
+        
+        int nb_rows = rows();
     	int nb_columns = columns();
     	double missing =  matrix_.missing();    
     	        	
@@ -234,20 +235,24 @@ public :
     }
     
     double min() const {
-      	 if ( min_ != INT_MAX) 
+       
+      	if ( min_ != INT_MAX) 
       		 return min_;
       	
       	setMinMax();
-      	 return min_;
+      	return min_;
+        
      }
      
-       double max() const {
-      	 if ( max_ != -INT_MAX) 
+    double max() const {
+       
+    	 
+        if ( max_ != -INT_MAX) 
       		 return max_; 
-      	 
+      	
       	setMinMax();
-      	 return max_;
-       }
+      	return max_;
+    }
     
     virtual double  minX() const { return matrix_.minX(); }
     virtual double  maxX() const { return matrix_.maxX(); }
@@ -637,10 +642,12 @@ public:
         }
         return -1;
     }
+
     
+   
     inline double column(int, int column) const {   	
        	return regular_longitudes_[column];
-   }
+    }
     inline double row(int row, int) const {
     	return regular_latitudes_[row];
     }
