@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file GribDecoder.h
     \brief Definition of the Template class GribDecoder.
@@ -105,9 +97,13 @@ public:
 	MatrixHandler& direction();
 	// Data Interface : info for the layer managment!
 	 string layerId()  { decode(); return layerId_; }
-	 string name() { decode(); return name_; }
-	 const DateTime& from() { decode(); return from_; }
-	 const DateTime& to()  { decode(); return to_; }
+	 string name() {
+
+	 	 return name_;
+	 }
+	 const DateTime& from() {
+	 return from_; }
+	 const DateTime& to()  {  return to_; }
 
 	string title() {
 		return title_;
@@ -207,7 +203,7 @@ public:
 
     string    getstring(const string&, bool warnIfKeyAbsent = true, bool cache= true) const;
 
-	void      read(Matrix **matrix);
+	void      read(Matrix **matrix, Matrix ** matrix2 = NULL);
 	void      read(Matrix **matrix, const Transformation&);
 	bool      id(const string&, const string&) const;
 
@@ -216,6 +212,10 @@ public:
 
 	grib_handle*  uHandle(string&);
 	grib_handle*  vHandle(string&);
+
+	grib_handle*  uHandle() const { return component1_ ; }
+	grib_handle*  vHandle() const { return component2_ ; };
+
 	grib_handle*  cHandle(string&);
 
 	double uComponent(int);
@@ -311,11 +311,13 @@ public:
 	void openFirstComponent() {
 		ASSERT(handle1_);
 		handle_ = handle1_;
+		component1_ = handle1_;
 	}
 
 	void openSecondComponent() {
 		ASSERT(handle2_);
 		handle_ = handle2_;
+		component2_ = handle2_;
 	}
 	void openThirdComponent() {
 			ASSERT(handle3_);
