@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file BaseDriver.cc
     \brief Implementation of driver base class.
@@ -266,13 +258,12 @@ string BaseDriver::getFileName(const string &extension, const unsigned int no) c
 
 	if( (no2 > 1) || firstnumber_ || legacy )
 	{
-		char *ostr;
-		if(numberWidth==4)      {ostr=new char[5]; sprintf(ostr,"%04u",no2);}
-		else if(numberWidth==3) {ostr=new char[4]; sprintf(ostr,"%03u",no2);}
-		else if(numberWidth==2) {ostr=new char[3]; sprintf(ostr,"%02u",no2);}
-		else                    {ostr=new char[2]; sprintf(ostr,"%u",no2);}
+		char ostr[8];
+		if(numberWidth==4)      {sprintf(ostr,"%04u",no2);}
+		else if(numberWidth==3) {sprintf(ostr,"%03u",no2);}
+		else if(numberWidth==2) {sprintf(ostr,"%02u",no2);}
+		else                    {sprintf(ostr,"%u",no2);}
 		filename += separator_+ostr+ext;
-		delete [] ostr;
 	}
 	else // if first page no number
 	{
@@ -947,11 +938,14 @@ void BaseDriver::redisplay(const BinaryObject& binary) const
 
 			for(int pts=0;pts<n;pts++)
 			{
-			  double x,y;
-			  in.read((char *)(&x), sizeof(double));
-			  in.read((char *)(&y), sizeof(double));
-			  PaperPoint p;
-			  in.read((char *)(&p), sizeof(PaperPoint));
+			  double x,y,ax,ay;
+			  in.read((char *)(&x),  sizeof(double));
+			  in.read((char *)(&y),  sizeof(double));
+			  in.read((char *)(&ax), sizeof(double));
+			  in.read((char *)(&ay), sizeof(double));
+			  //PaperPoint p;
+			  //in.read((char *)(&p), sizeof(PaperPoint));
+			  PaperPoint p(ax,ay);
 			  ArrowPoint ap(x, y, p);
 			  arrow.push_back(ap);
 			} 
@@ -995,14 +989,17 @@ void BaseDriver::redisplay(const BinaryObject& binary) const
 			tex[len]='\0';
 			string str(tex);
 			flag.setOriginMarker(str);
-
+	
 			for(int pts=0;pts<n;pts++)
 			{
-			  double x,y;
-			  in.read((char *)(&x), sizeof(double));
-			  in.read((char *)(&y), sizeof(double));
-			  PaperPoint p;
-			  in.read((char *)(&p), sizeof(PaperPoint));
+			  double x,y,ax,ay;
+			  in.read((char *)(&x),  sizeof(double));
+			  in.read((char *)(&y),  sizeof(double));
+			  in.read((char *)(&ax), sizeof(double));
+			  in.read((char *)(&ay), sizeof(double));
+			  //PaperPoint p;
+			  //in.read((char *)(&p), sizeof(PaperPoint));
+			  PaperPoint p(ax,ay);
 			  ArrowPoint ap(x, y, p);
 			  flag.push_back(ap);
 			} 
