@@ -1,22 +1,12 @@
-/******************************** LICENSE ********************************
-
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at
-
- 	http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file GeoJsonDriver.cc
     \brief Implementation of GeoJsonDriver.
@@ -80,9 +70,9 @@ void GeoJsonDriver::open()
 	pFile_.open(fileName_.c_str());
 	if(!pFile_)
 	{
-		MagLog::error() << "GeoJsonDriver::open() --> Cannot open GeoJson output file: " << fileName_ << "!\n";
-		MagLog::error() << "";  // to ensure that the error message is broadcast
-		terminate();
+		MagLog::error() << " GeoJsonDriver --> Cannot write output file to what was specified: "<<fileName_<< endl;
+		MagLog::error() << "";
+		throw NoSuchFileException("Error opening GeoJson output file!");
 	}
 /*	pFile_	<< "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>\n"
 		<< "<GeoJson xmlns=\"http://www.opengis.net/GeoJson/2.2\" \n"
