@@ -1,29 +1,18 @@
-/******************************** LICENSE ********************************
-
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
- 
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License. 
- You may obtain a copy of the License at
- 
- 	http://www.apache.org/licenses/LICENSE-2.0
- 
- Unless required by applicable law or agreed to in writing, software 
- distributed under the License is distributed on an "AS IS" BASIS, 
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
- See the License for the specific language governing permissions and 
- limitations under the License.
-
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file SVGDriver.cc
     \brief Implementation of SVGDriver.
     \author Meteorological Visualisation Section, ECMWF
 
     Started: Fri Oct 26 20:58:21 2007
-
 */
 
 #include <SVGDriver.h>
@@ -126,9 +115,9 @@ MAGICS_NO_EXPORT void SVGDriver::startPage() const
 
 	if(!pFile_)
 	{
-		MagLog::error() << "SVGDriver::startPage() --> Cannot open SVG output file: " << filename << "\n";
-		MagLog::error() << "";  // to ensure that the error message is broadcast
-		terminate();
+		MagLog::error() << " SVGDriver --> Cannot write output file to what was specified: "<<fileName_<< endl;
+		MagLog::error() << "";
+		throw NoSuchFileException("Error opening SVG output file!");
 	}
 
 	svg_output_resource_list_.push_back(filename);
@@ -1396,54 +1385,33 @@ else
 */
 MAGICS_NO_EXPORT void SVGDriver::renderImage(const ImportObject& obj) const
 {
-	closeGroup();
-	std::string file = obj.getPath();
-
-	string format = obj.getFormat();
-	if(magCompare(format,"ps") || magCompare(format,"pdf"))
+/*	if(magCompare(logoLocation_,"LOCAL"))
 	{
-		std::string cmd = "convert "+file+"[1] ___magics_svg_temp.png";
-		MagLog::info() <<"SVGDriver::renderImage calling convert ... with: " <<cmd << endl;
-		int status = system(cmd.c_str());
-		if(status)
-		{
-			MagLog::error() << "\nSVGDriver: Command exit not zero - NO PNG produced!\n"
-			             << " COMMAND: "<<cmd<<"\n"<< endl;
-			return;
-		}
-		file="___magics_svg_temp.png";
-	}
+	  closeGroup();
+	  std::string file = obj.getPath();
 
-	const MFloat w = (obj.getWidth()<0)  ? 30./coordRatioX_ : obj.getWidth();
-	const MFloat h = (obj.getHeight()<0) ? 30./coordRatioY_ : obj.getHeight();
+	  string format = obj.getFormat();
 
-	if(!magCompare(format,"svg"))
-	{
-		const MFloat x = projectX(obj.getOrigin().x());
-		const MFloat y = projectY(obj.getOrigin().y());
-		const MFloat oh = projectY(obj.getOrigin().y()+h) - y;
-		const MFloat ow = projectX(obj.getOrigin().x()+w) - x;
+	  const MFloat w = (obj.getWidth()<0)  ? 30./coordRatioX_ : obj.getWidth();
+	  const MFloat h = (obj.getHeight()<0) ? 30./coordRatioY_ : obj.getHeight();
 
-		const ImageProperties::OriginReference ori = obj.getOriginReference();
-		if(ori == ImageProperties::centre)
+	  const MFloat x = projectX(obj.getOrigin().x());
+	  const MFloat y = projectY(obj.getOrigin().y());
+	  const MFloat oh = projectY(obj.getOrigin().y()+h) - y;
+	  const MFloat ow = projectX(obj.getOrigin().x()+w) - x;
+
+	  const ImageProperties::OriginReference ori = obj.getOriginReference();
+	  if(ori == ImageProperties::centre)
 			pFile_ << "<image x=\""<<x-(ow*.5)<<"\" y=\""<<setY(y)-(oh*.5);
-		else
+	  else
 			pFile_ << "<image x=\""<<x<<"\" y=\""<<setY(y)-oh;
-		pFile_  <<"\" width=\""  << ow
+	  pFile_  <<"\" width=\""  << ow
 		        <<"\" height=\"" << oh
 		        <<"\" xlink:href=\""<<file<<"\" />\n";
 	}
-	else
+	else */
 	{
-		ifstream svgfile(file.c_str());
-		if(!svgfile){
-			MagLog::error() << "SVGDriver::renderImage() --> Cannot open SVG file! " << file <<"!\n";
-			return;
-		}
-		char ch;
-		while (svgfile.get(ch)){pFile_.put(ch);}
-		svgfile.close();
-		svg_output_resource_list_.push_back(file);
+		BaseDriver::renderImage(obj);
 	}
 }
 
