@@ -2,7 +2,7 @@
 ** Copyright (C) 1989, 1991 by Jef Poskanzer.
 ** Copyright (C) 1997, 2000, 2002 by Greg Roelofs; based on an idea by
 **                                Stefan Schneider.
-** © 2009-2013 by Kornel Lesinski.
+** © 2009-2015 by Kornel Lesinski.
 **
 ** Permission to use, copy, modify, and distribute this software and its
 ** documentation for any purpose and without fee is hereby granted, provided
@@ -21,7 +21,7 @@
 
 #define index_of_channel(ch) (offsetof(f_pixel,ch)/sizeof(float))
 
-static f_pixel averagepixels(unsigned int clrs, const hist_item achv[], float min_opaque_val, const f_pixel center);
+static f_pixel averagepixels(unsigned int clrs, const hist_item achv[], const f_pixel center);
 
 struct box {
     f_pixel color;
@@ -228,7 +228,7 @@ static f_pixel get_median(const struct box *b, hist_item achv[])
 
     // technically the second color is not guaranteed to be sorted correctly
     // but most of the time it is good enough to be useful
-    return averagepixels(2, &achv[b->ind + median_start], 1.0, (f_pixel){0.5,0.5,0.5,0.5});
+    return averagepixels(2, &achv[b->ind + median_start], (f_pixel){0.5,0.5,0.5,0.5});
 }
 
 /*
@@ -269,7 +269,7 @@ inline static double color_weight(f_pixel median, hist_item h)
 static void set_colormap_from_boxes(colormap *map, struct box* bv, unsigned int boxes, hist_item *achv);
 static void adjust_histogram(hist_item *achv, const colormap *map, const struct box* bv, unsigned int boxes);
 
-double box_error(const struct box *box, const hist_item achv[])
+static double box_error(const struct box *box, const hist_item achv[])
 {
     f_pixel avg = box->color;
 
@@ -311,7 +311,7 @@ static bool total_box_error_below_target(double target_mse, struct box bv[], uns
  ** on Paul Heckbert's paper, "Color Image Quantization for Frame Buffer
  ** Display," SIGGRAPH 1982 Proceedings, page 297.
  */
-LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, unsigned int newcolors, const double target_mse, const double max_mse, void* (*malloc)(size_t), void (*free)(void*))
+LIQ_PRIVATE colormap *mediancut(histogram *hist, unsigned int newcolors, const double target_mse, const double max_mse, void* (*malloc)(size_t), void (*free)(void*))
 {
     hist_item *achv = hist->achv;
     struct box bv[newcolors];
@@ -321,7 +321,7 @@ LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, uns
      */
     bv[0].ind = 0;
     bv[0].colors = hist->size;
-    bv[0].color = averagepixels(bv[0].colors, &achv[bv[0].ind], min_opaque_val, (f_pixel){0.5,0.5,0.5,0.5});
+    bv[0].color = averagepixels(bv[0].colors, &achv[bv[0].ind], (f_pixel){0.5,0.5,0.5,0.5});
     bv[0].variance = box_variance(achv, &bv[0]);
     bv[0].max_error = box_max_error(achv, &bv[0]);
     bv[0].sum = 0;
@@ -330,20 +330,11 @@ LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, uns
 
     unsigned int boxes = 1;
 
-    // remember smaller palette for fast searching
-    colormap *representative_subset = NULL;
-    unsigned int subset_size = ceilf(powf(newcolors,0.7f));
-
     /*
      ** Main loop: split boxes until we have enough.
      */
     while (boxes < newcolors) {
 
-        if (boxes == subset_size) {
-            representative_subset = pam_colormap(boxes, malloc, free);
-            set_colormap_from_boxes(representative_subset, bv, boxes, achv);
-        }
-
         // first splits boxes that exceed quality limit (to have colors for things like odd green pixel),
         // later raises the limit to allow large smooth areas/gradients get colors.
         const double current_max_mse = max_mse + (boxes/(double)newcolors)*16.0*max_mse;
@@ -383,14 +374,14 @@ LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, uns
         const f_pixel previous_center = bv[bi].color;
         bv[bi].colors = break_at;
         bv[bi].sum = lowersum;
-        bv[bi].color = averagepixels(bv[bi].colors, &achv[bv[bi].ind], min_opaque_val, previous_center);
+        bv[bi].color = averagepixels(bv[bi].colors, &achv[bv[bi].ind], previous_center);
         bv[bi].total_error = -1;
         bv[bi].variance = box_variance(achv, &bv[bi]);
         bv[bi].max_error = box_max_error(achv, &bv[bi]);
         bv[boxes].ind = indx + break_at;
         bv[boxes].colors = clrs - break_at;
         bv[boxes].sum = sm - lowersum;
-        bv[boxes].color = averagepixels(bv[boxes].colors, &achv[bv[boxes].ind], min_opaque_val, previous_center);
+        bv[boxes].color = averagepixels(bv[boxes].colors, &achv[bv[boxes].ind], previous_center);
         bv[boxes].total_error = -1;
         bv[boxes].variance = box_variance(achv, &bv[boxes]);
         bv[boxes].max_error = box_max_error(achv, &bv[boxes]);
@@ -405,7 +396,6 @@ LIQ_PRIVATE colormap *mediancut(histogram *hist, const float min_opaque_val, uns
     colormap *map = pam_colormap(boxes, malloc, free);
     set_colormap_from_boxes(map, bv, boxes, achv);
 
-    map->subset_palette = representative_subset;
     adjust_histogram(achv, map, bv, boxes);
 
     return map;
@@ -443,7 +433,22 @@ static void adjust_histogram(hist_item *achv, const colormap *map, const struct
     }
 }
 
-static f_pixel averagepixels(unsigned int clrs, const hist_item achv[], const float min_opaque_val, const f_pixel center)
+inline static f_pixel setalpha(f_pixel px, float new_a) {
+    if (px.a) {
+        px.r /= px.a;
+        px.g /= px.a;
+        px.b /= px.a;
+    }
+
+    px.r *= new_a;
+    px.g *= new_a;
+    px.b *= new_a;
+    px.a = new_a;
+
+    return px;
+}
+
+static f_pixel averagepixels(unsigned int clrs, const hist_item achv[], f_pixel center)
 {
     double r = 0, g = 0, b = 0, a = 0, new_a=0, sum = 0;
     float maxa = 0;
@@ -460,14 +465,13 @@ static f_pixel averagepixels(unsigned int clrs, const hist_item achv[], const fl
 
     if (sum) new_a /= sum;
 
-    /** if there was at least one completely opaque color, "round" final color to opaque */
-    if (new_a >= min_opaque_val && maxa >= (255.0/256.0)) new_a = 1;
+    center = setalpha(center, new_a);
 
     sum=0;
     // reverse iteration for cache locality with previous loop
     for(int i = clrs-1; i >= 0; i--) {
         double tmp, weight = 1.0f;
-        f_pixel px = achv[i].acolor;
+        f_pixel px = setalpha(achv[i].acolor, new_a);
 
         /* give more weight to colors that are further away from average
          this is intended to prevent desaturation of images and fading of whites
@@ -478,27 +482,23 @@ static f_pixel averagepixels(unsigned int clrs, const hist_item achv[], const fl
         weight += tmp*tmp;
         tmp = (center.b - px.b);
         weight += tmp*tmp;
+        tmp = (center.a - px.a);
+        weight += tmp*tmp;
 
         weight *= achv[i].adjusted_weight;
         sum += weight;
 
-        if (px.a) {
-            px.r /= px.a;
-            px.g /= px.a;
-            px.b /= px.a;
-        }
-
-        r += px.r * new_a * weight;
-        g += px.g * new_a * weight;
-        b += px.b * new_a * weight;
-        a += new_a * weight;
+        r += px.r * weight;
+        g += px.g * weight;
+        b += px.b * weight;
+        a += px.a * weight;
     }
 
     if (sum) {
-    a /= sum;
-    r /= sum;
-    g /= sum;
-    b /= sum;
+        a /= sum;
+        r /= sum;
+        g /= sum;
+        b /= sum;
     }
 
     assert(!isnan(r) && !isnan(g) && !isnan(b) && !isnan(a));
