@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file Contour.cc
     \brief Implementation of the Template class Contour.
@@ -33,6 +25,7 @@
 #include "Text.h"
 #include "ContourLibrary.h"
 #include "HistoVisitor.h"
+#include "Timer.h"
 
 using namespace magics;
 
@@ -128,8 +121,25 @@ void Contour::operator()(Data& data, BasicGraphicsObjectContainer& parent)
 	if (this->floor_ != -INT_MAX || this->ceiling_ != INT_MAX)
 		matrix_ = new MatrixTreshold(*matrix_, this->floor_, this->ceiling_);
 
-	(*this->contour_).adjust(matrix_->min(), matrix_->max());
-	(*this->contour_)(*matrix_, parent);
+	{
+		Timer timer("setMinMax", "setMainMax");
+		double min, max;
+		{
+			Timer timer("Max", "Max");
+			min = matrix_->min();
+			
+		}
+		{
+			Timer timer("MIN", "MIN");
+			max = matrix_->max();
+		}	
+		(*this->contour_).adjust(min, max);
+			
+	}
+	{
+		Timer timer("CONTOUR", "CONTOUR");
+		(*this->contour_)(*matrix_, parent);
+	}
 	(*this->contour_)(data, parent);
 	if ( magCompare( this->grid_->getType(), "akima" ) )
 		(*this->grid_)(*matrix_, parent);
