@@ -28,6 +28,24 @@
 
 using namespace magics;
 
+
+template <class T, class O>
+void setHandler(const vector<string>& keys, vector<T>& values, ListPolicy policy, const T& def, map<string, O>& handler) 
+{
+	if (values.empty())
+		values.push_back(def);
+
+	typename vector<T>::const_iterator value = values.begin();
+	MagTranslator<T, O> translator;
+	for (vector<string>::const_iterator key = keys.begin(); key != keys.end(); ++key) {
+		
+		handler.insert(make_pair(*key, translator(*value)));
+		value++;
+		if ( value == values.end() )
+			value = ( policy ==  M_CYCLE ) ? values.begin() : --value;
+	}
+}
+
 Curve::Curve() 
 {
 	missingMethods_["ignore"] = &Curve::ignore;
@@ -36,7 +54,9 @@ Curve::Curve()
 
 	curveMethods_["straight"] = &Curve::straight;
 	curveMethods_["stepped"] = &Curve::stepped;
+	
 
+	
 }
 
 
@@ -56,9 +76,12 @@ Polyline* Curve::newCurve(BasicGraphicsObjectContainer& task) const
 {
 
 	Polyline* curve  = new Polyline();
-	(*curve).setColour(*colour_);
-	(*curve).setLineStyle(style_);
-	(*curve).setThickness(thickness_);
+	
+
+	(*curve).setColour(currentColour_);
+	(*curve).setLineStyle(currentStyle_);
+	(*curve).setThickness(currentThickness_);
+
 
 	return curve;
 	
@@ -87,6 +110,17 @@ void  Curve::stepped(const UserPoint& point, vector<UserPoint>& out)
 {
 
 
+}
+
+template <class T>
+const T& get(const map<string, T>& handler, const string& key, const T& def) 
+{
+	
+	typename std::map<string, T>::const_iterator value = handler.find(key);
+	if ( value == handler.end() ) 
+		return def;
+	return value->second;
+
 }
 
 void Curve::operator()(Data& data, BasicGraphicsObjectContainer& task)
@@ -98,13 +132,42 @@ void Curve::operator()(Data& data, BasicGraphicsObjectContainer& task)
 
 
     std::set<string> needs;
+    std::map<string, string> info;
+
+    currentColour_ = *colour_;
+	currentThickness_ = thickness_;
+	currentStyle_ = style_;
+    
+    if ( magCompare(style_setting_, "advanced")  ) {
+    	string style = "solid";
+ 		setHandler(colour_keys_, colour_list_, colour_policy_, colour_->name(), colourHandler_);
+		setHandler(thickness_keys_, thickness_list_, thickness_policy_, thickness_, thicknessHandler_);
+		setHandler(style_keys_, style_list_, style_policy_, style, styleHandler_);
+
+    	info.insert(make_pair(style_key_, ""));
+    	info.insert(make_pair(colour_key_, ""));
+    	info.insert(make_pair(thickness_key_, ""));
+		data.getInfo(info);
+		
+		string colour = get(colourHandler_, info[colour_key_], currentColour_.name());
+		currentColour_ = Colour(colour);
+		currentThickness_ = get(thicknessHandler_, info[thickness_key_], currentThickness_);
+		currentStyle_ = get(styleHandler_, info[style_key_], currentStyle_);
+	}
+
+
+	
+
+	
+	
+
+
     CustomisedPointsList raw, points;
 
     data.customisedPoints(transformation, needs, points, true);
 
 	if ( legend_text_ == "?" ) legend_text_ = data.legend(); 
 	
-	
 	Polyline* curve_ = newCurve(task);
 	bool last_out = false;	
 	
@@ -215,7 +278,10 @@ void CurveArea::operator()(Data& data, BasicGraphicsObjectContainer& task)
 	vector<double> ypos;
     const Transformation& transformation = task.transformation();
 
-
+    currentColour_ = *colour_;
+	currentThickness_ = thickness_;
+	currentStyle_ = style_;
+    
     std::set<string> needs;
     CustomisedPointsList points;
     if ( shade_->needCustomised() ) {
@@ -321,9 +387,9 @@ void Curve::visit(LegendVisitor& legend)
 void  Curve::set(const PaperPoint& point, BasicGraphicsObjectContainer& legend, LegendEntry& entry)
 {
 	Polyline* curve  = new Polyline();
-	curve->setColour(*colour_);
-	curve->setLineStyle(style_);
-	curve->setThickness(thickness_);
+	curve->setColour(currentColour_);
+	curve->setLineStyle(currentStyle_);
+	curve->setThickness(currentThickness_);
 	
 	double width = entry.computeWidth(0.8)/2;
 
@@ -375,7 +441,6 @@ void Curve::legend_symbol(PaperPoint& point, BasicGraphicsObjectContainer& task)
 	if ( !symbol_ ) return;
 
 	Symbol* symbol = new Symbol();
-
     symbol->setMarker(symbol_marker_);
     symbol->setHeight(symbol_height_);
     symbol->setColour(*symbol_colour_);
