@@ -1,21 +1,12 @@
-
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHvisitor WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file EpsGraph.cc
     \brief Implementation of the Template class EpsGraph.
@@ -742,7 +733,7 @@ void EpsGraph::operator()(Data& data, BasicGraphicsObjectContainer& visitor)
 
 
 		CustomisedPoint::const_iterator ten   = (*point)->find("ten");
-                CustomisedPoint::const_iterator ninty = (*point)->find("ninty");
+                CustomisedPoint::const_iterator ninty = (*point)->find("ninety");
 
 
 
@@ -751,8 +742,8 @@ void EpsGraph::operator()(Data& data, BasicGraphicsObjectContainer& visitor)
 
         if ( (*point)->find("control") != (*point)->end() &&  (**point)["control"]!= 9999.  )
         	control->push_back(PaperPoint(x, (**point)["control"]));		
-		if ( (*point)->find("forecast") != (*point)->end() &&  (**point)["forecast"] != 9999.)
-            forecast->push_back(PaperPoint(x, (**point)["forecast"]));
+		if ( (*point)->find("hres") != (*point)->end() &&  (**point)["hres"] != 9999.)
+            forecast->push_back(PaperPoint(x, (**point)["hres"]));
         if ( (*point)->find("median") == (*point)->end() )  {        	
             eps_ = false;  
             continue;
@@ -765,10 +756,10 @@ void EpsGraph::operator()(Data& data, BasicGraphicsObjectContainer& visitor)
 	vector<double> eps;
 	eps.push_back( (**point)["min"]);
 	eps.push_back( (**point)["ten"]);
-	eps.push_back( (**point)["twentyfive"]);
+	eps.push_back( (**point)["twenty_five"]);
 	eps.push_back( (**point)["median"]);
-	eps.push_back( (**point)["seventyfive"]);
-	eps.push_back( (**point)["ninty"]);
+	eps.push_back( (**point)["seventy_five"]);
+	eps.push_back( (**point)["ninety"]);
 	eps.push_back( (**point)["max"]);
 
 	std::sort(eps.begin(), eps.end());
@@ -796,17 +787,34 @@ void EpsGraph::operator()(Data& data, BasicGraphicsObjectContainer& visitor)
         	eps75 = eps[3];
         	epsmax = eps[4];
 	}
+	// Prepare the colors :
+	int size = quantiles_colour_.size();
+	Colour colour10_25 = ( size >= 1 ) ? Colour(quantiles_colour_[0]) : colour;
+	Colour colour25_75 = ( size >= 2 ) ? Colour(quantiles_colour_[1]) : colour;
+	Colour colour75_90 = ( size >= 3 ) ? Colour(quantiles_colour_[2]) : colour10_25;
+
+		Polyline* box10_25  = new Polyline();
+		box10_25->setColour(*border_colour_);
+		box10_25->setThickness(border_thickness_);
+		box10_25->setFilled(true);
+		box10_25->setFillColour(colour10_25);
+		box10_25->setShading(new FillShadingProperties());
+        
+        Polyline* box25_75  = new Polyline();
+		box25_75->setColour(*border_colour_);
+		box25_75->setThickness(border_thickness_);
+		box25_75->setFilled(true);
+		box25_75->setFillColour(colour25_75);
+		box25_75->setShading(new FillShadingProperties());
+		
+		Polyline* box75_90  = new Polyline();
+		box75_90->setColour(*border_colour_);
+		box75_90->setThickness(border_thickness_);
+		box75_90->setFilled(true);
+		box75_90->setFillColour(colour75_90);
+		box75_90->setShading(new FillShadingProperties());
 
-		Polyline* box  = new Polyline();
-		box->setColour(*border_colour_);
-		box->setThickness(border_thickness_);
 
-		box->setColour(*border_colour_);
-		box->setFilled(true);
-		box->setThickness(border_thickness_);
-		box->setFillColour(colour);
-		box->setShading(new FillShadingProperties());
-      
         Polyline* median  = new Polyline();
         median->setColour(*median_colour_);
         
@@ -818,35 +826,35 @@ void EpsGraph::operator()(Data& data, BasicGraphicsObjectContainer& visitor)
         bar2->setColour(*border_colour_);
         bar2->setThickness(border_thickness_);
 
-        box->push_back(PaperPoint(x-width, eps50));
-		box->push_back(PaperPoint(x-width, eps75));
+        box25_75->push_back(PaperPoint(x-width, eps50));
+		box25_75->push_back(PaperPoint(x-width, eps75));
         
         if ( ninty != (*point)->end() ) {
         	fullEps_ = true;
         	if ( eps75 != eps90 ) {
-            box->push_back(PaperPoint(x-(width/2), eps75));
-            box->push_back(PaperPoint(x-(width/2), eps90) );
-            box->push_back(PaperPoint(x+(width/2), eps90));
-            box->push_back(PaperPoint(x+(width/2), eps75));
+            box75_90->push_back(PaperPoint(x-(width/2), eps75));
+            box75_90->push_back(PaperPoint(x-(width/2), eps90) );
+            box75_90->push_back(PaperPoint(x+(width/2), eps90));
+            box75_90->push_back(PaperPoint(x+(width/2), eps75));
         	}
             
         }
         if ( eps75 != eps25 ) {
-		box->push_back(PaperPoint(x+width, eps75));
-		box->push_back(PaperPoint(x+width, eps25));
+		box25_75->push_back(PaperPoint(x+width, eps75));
+		box25_75->push_back(PaperPoint(x+width, eps25));
         }
         if ( ten != (*point)->end() ) {
         	if ( eps25 != eps10 ) {
 
-            box->push_back(PaperPoint(x+(width/2), eps25));
-            box->push_back(PaperPoint(x+(width/2),eps10));
-            box->push_back(PaperPoint(x-(width/2), eps10));
-            box->push_back(PaperPoint(x-(width/2), eps25));
+            box10_25->push_back(PaperPoint(x+(width/2), eps25));
+            box10_25->push_back(PaperPoint(x+(width/2),eps10));
+            box10_25->push_back(PaperPoint(x-(width/2), eps10));
+            box10_25->push_back(PaperPoint(x-(width/2), eps25));
         	}
         }
         if ( eps25 != eps50 ) {
-        box->push_back(PaperPoint(x-width, eps25));
-        box->push_back(PaperPoint(x-width, eps50));
+        box25_75->push_back(PaperPoint(x-width, eps25));
+        box25_75->push_back(PaperPoint(x-width, eps50));
         }
     	bar1->push_back(PaperPoint(x+width, eps25));
     	bar1->push_back(PaperPoint(x-width, eps25));
@@ -879,7 +887,9 @@ void EpsGraph::operator()(Data& data, BasicGraphicsObjectContainer& visitor)
            (*bottom).push_back(PaperPoint(x, eps25));
 		
 		if (whisker_) {
-            transformation(*box, visitor);
+            transformation(*box10_25, visitor); 
+            transformation(*box25_75, visitor); 
+            transformation(*box75_90, visitor);
             transformation(*top, visitor);
             transformation(*bottom, visitor);
             transformation(*median, visitor);
@@ -896,8 +906,8 @@ void EpsGraph::operator()(Data& data, BasicGraphicsObjectContainer& visitor)
 				ypos.push_back(min);
 				if ( (*point)->find("control") != (*point)->end() )
 					ypos.push_back((**point)["control"]);
-			    if ( (*point)->find("forecast") != (*point)->end() )
-				    ypos.push_back((**point)["forecast"]);
+			    if ( (*point)->find("hres") != (*point)->end() )
+				    ypos.push_back((**point)["hres"]);
 		    
 		    }
 		
@@ -943,6 +953,149 @@ void EpsGraph::operator()(Data& data, BasicGraphicsObjectContainer& visitor)
      	
 		
 
+}
+
+void EpsLight::print(ostream& visitor)  const
+{
+	visitor << "EpsLight[";
+	visitor << "]";
+}
+
+
+
+void EpsLight::operator()(Data& data, BasicGraphicsObjectContainer& visitor)
+{
+
+/*
+	#6AE9FF,#B0EBF5,#B4DAE0,#A3BBBF,#889B9E,#6AE9FF,#B0EBF5,#B4DAE0
+	Hsl hsl = colour.hsl();
+    
+    float light = hsl.light_;
+   
+    hsl.light_ += (0.99 - light)*((point["total"]- point[direction.first])/point["total"]);
+*/
+   	
+   	vector<Colour> colours;
+
+   	colours.push_back(Colour("#6AE9FF"));
+   
+   	colours.push_back(Colour("#B0EBF5"));
+
+	colours.push_back(Colour("#B4DAE0"));
+	
+	colours.push_back(Colour("#A3BBBF"));
+	
+	colours.push_back(Colour("#889B9E"));
+	
+	
+   	CustomisedPointsList points; 
+	std::set<string> request;
+
+	const Transformation& transformation = visitor.transformation();
+	
+	data.customisedPoints(transformation, request, points, true); // we want all the points!
+
+	
+	if (points.empty()) return;
+	
+    
+    
+    if ( points.size() < 2 ) return;
+    
+    
+	for (CustomisedPointsList::const_iterator point = points.begin(); point != points.end(); ++point) {
+	
+		
+		double x = (**point)["step"];
+		double width = (3600*3);
+		
+		double max = ((*point)->find("max") != (*point)->end()) ? (*point)->find("max")->second : (*point)->find("maximum")->second;
+		double min = ((*point)->find("min") != (*point)->end()) ? (*point)->find("min")->second : (*point)->find("minimum")->second;
+
+
+		CustomisedPoint::const_iterator ten   = (*point)->find("ten");
+        CustomisedPoint::const_iterator ninty = (*point)->find("ninety");
+
+	      
+		vector<double> eps;
+		eps.push_back( (**point)["min"]);
+		eps.push_back( (**point)["ten"]);
+		eps.push_back( (**point)["twenty_five"]);
+		eps.push_back( (**point)["median"]);
+		eps.push_back( (**point)["seventy_five"]);
+		eps.push_back( (**point)["ninety"]);
+		eps.push_back( (**point)["max"]);
+
+		std::sort(eps.begin(), eps.end());
+
+		for (vector<double>::iterator e = eps.begin(); e != eps.end(); ++e) {
+			if ( same(*e, 0) )
+				*e = 0;
+	        cout << *e << " ";
+	    }
+	    cout << endl;
+
+        double epsmin, eps10, eps25,  eps50, eps75, eps90, epsmax;
+        if ( ninty != (*point)->end() ) {
+        	epsmin = eps[0];
+        	eps10 = eps[1];
+       		eps25 = eps[2];
+        	eps50 = eps[3];
+        	eps75 = eps[4];
+        	eps90 = eps[5];
+        	epsmax = eps[6];
+		}
+		else {
+	        	epsmin = eps[0];
+	       		eps25 = eps[1];
+	        	eps50 = eps[2];
+	        	eps75 = eps[3];
+	        	epsmax = eps[4];
+		}
+
+		if ( epsmax == 0 )
+			continue;
+
+		map<double, float> lights;
+
+		lights[epsmin] = 0;
+		lights[eps10] = 0.20;
+		lights[eps25] = 0.50;
+		
+
+		float y = 1.;
+		float height = 1./(colours.size()*4);
+
+		for ( vector<Colour>::iterator colour = colours.begin(); colour != colours.end(); ++colour) {
+			cout << x << "  " << x + width << endl;
+			for (int i = 0; i < 4; i++ ) {
+				Polyline* box  = new Polyline();
+				box->setColour(*colour);
+				box->setFilled(true);
+				box->setFillColour(*colour);
+/*
+				Hsl hsl = colour->hsl();
+	    		float light = hsl.light_;
+	    		hsl.light_ += (0.99 - light)*((point["total"]- point[direction.first])/point["total"]);
+*/				
+				box->setShading(new FillShadingProperties());
+				box->push_back(PaperPoint(x+width, y));
+				box->push_back(PaperPoint(x-width, y));
+
+				box->push_back(PaperPoint(x-width, y-height));
+				box->push_back(PaperPoint(x+width, y-height));
+				box->push_back(PaperPoint(x+width, y));
+				y -= height;
+				transformation(*box, visitor); 
+			}
+		} 
+	}
+
+}
+
+void EpsLight::visit(LegendVisitor& legend)
+{
+
 }
 
 void EpsGraph::visit(LegendVisitor& legend)
@@ -1688,14 +1841,14 @@ void EpsWave::operator()(Data& data, BasicGraphicsObjectContainer& visitor)
 		}
 
 		// Draw the Forecast
-		if ( (*point)->find("forecast") != (*point)->end() ) {
+		if ( (*point)->find("hres") != (*point)->end() ) {
 			Polyline* hres = new Polyline();
 			hres->setColour(Colour("blue"));
 			hres->setThickness(2);
 			hres->setLineStyle(M_SOLID);
 
 
-			double angle = (**point)["forecast"]-180;
+			double angle = (**point)["hres"]-180;
 			hres->push_back(PaperPoint(x , 0));
 			hres->push_back(PaperPoint(x +(l100 * sin(angle*(3.14/180.))), l100 * cos(angle*(3.14/180.))));
 			visitor.push_back(hres);
@@ -2028,13 +2181,13 @@ void EpsShade::operator()(Data& data, BasicGraphicsObjectContainer& visitor)
 		
         
 		
-		CustomisedPoint::const_iterator y1 = (*point)->find("1");       
-		CustomisedPoint::const_iterator y10 = (*point)->find("10");
-        CustomisedPoint::const_iterator y90 = (*point)->find("90");
-        CustomisedPoint::const_iterator y99 = (*point)->find("99");  
-		CustomisedPoint::const_iterator y50 = (*point)->find("50");
-		CustomisedPoint::const_iterator y25 = (*point)->find("25");
-		CustomisedPoint::const_iterator y75 = (*point)->find("75");
+		CustomisedPoint::const_iterator y1 = (*point)->find("one");       
+		CustomisedPoint::const_iterator y10 = (*point)->find("ten");
+        CustomisedPoint::const_iterator y90 = (*point)->find("ninety");
+        CustomisedPoint::const_iterator y99 = (*point)->find("ninety_nine");  
+		CustomisedPoint::const_iterator y50 = (*point)->find("fifty");
+		CustomisedPoint::const_iterator y25 = (*point)->find("twenty_five");
+		CustomisedPoint::const_iterator y75 = (*point)->find("seventy_five");
 
         if ( (**point)["tmin"] ) {		
             tenmin.push_back(PaperPoint(x, y10->second));
@@ -2552,7 +2705,7 @@ void EpsPlume::timeserie(Data& data, BasicGraphicsObjectContainer& visitor)
 			}
 
 			if ( forecast_ ) {
-			if ( value->first == "forecast" &&  value->second != missing )
+			if ( value->first == "hres" &&  value->second != missing )
 				forecast->push_back(PaperPoint(x, value->second));
 			}
 			if ( control_ ) {
@@ -2662,7 +2815,7 @@ void EpsPlume::verticalprofile(Data& data, BasicGraphicsObjectContainer& visitor
 				(iline->second)->push_back(transformation(UserPoint(value->second, y)));
 			}
 
-			if ( value->first == "forecast" )
+			if ( value->first == "hres" )
 				forecast->push_back(transformation(UserPoint(value->second, y)));
 			if ( value->first == "control" )
 				control->push_back(transformation(UserPoint(value->second, y)));
