@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 # (C) Copyright 1996-2016 ECMWF.
 # 
 # This software is licensed under the terms of the Apache Licence Version 2.0
@@ -289,14 +289,11 @@ EOF
  
     print  <<EOF;
 /*! \\file $object\Wrapper.h
-    \\brief Implemtation of $object Wrapper class.
+    \\brief Implementation of $object Wrapper class.
     Automatically generated on $string
     Do Not Edit!
-    
-    Magics Team - ECMWF 2004
-   
+
     Created: $string
-    
 */    
 
 #include "MagRequest.h" 
@@ -547,8 +544,11 @@ EOF
               }
               else {
                 print "\n#include \"$class\Wrapper.h\"\n";  
-                for my $o (@fortrans) { 	
-        	        print "static SimpleObjectMaker<$class\Wrapper, $base\Wrapper> $object\_$o\_$class\_w(\"$o\");\n" if $o ne "";
+                for my $o (@fortrans) { 
+                    $n = $o;
+                    $n =~ s/://;
+                    print "static SimpleObjectMaker<$class, $base> $n\_$class(\"$n\");\n" if $o ne "";	
+        	        print "static SimpleObjectMaker<$class\Wrapper, $base\Wrapper> $object\_$n\_$class\_w(\"$o\");\n" if $o ne "";
                 }
                 if ($xml ne "") {
                     if ($xml ne $fortran) {
